UserSetting class

user setting object

Constructors

UserSetting({required int user, required bool orderUpdateNotification, required bool promotionNotification, required int id})
UserSetting.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
orderUpdateNotification ↔ bool
getter/setter pair
promotionNotification ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited